@@ -40,7 +40,7 @@ void diff2hfunc_mod(double* u, double* v, int* n, double* param, int* copula, do
   nparam[0]=-param[0];
   nparam[1]=-param[1];
 
-if((*copula==43))
+if((*copula)==43)
 	{
 		ncopula=3;
 		if(param[0] > 0){
@@ -55,7 +55,7 @@ if((*copula==43))
 			diffhfunc(u, negv, n, nparam, &ncopula, out2);
 			for (i = 0; i < *n; i++) {out[i]=out[i]*4/pow(1+param[0],4)+out2[i]*4/pow(1+param[0],3);}
 		}
-	}else if((*copula==44))
+	}else if((*copula)==44)
 	{
 		ncopula=4;
 		if(param[0] > 0){
@@ -71,21 +71,21 @@ if((*copula==43))
 			for (i = 0; i < *n; i++) {out[i]=out[i]/pow(1+param[0],4)+out2[i]*2/pow(1+param[0],3);}
 		}
 	}else{
-  if(((*copula==23) | (*copula==24) | (*copula==26) | (*copula==27) | (*copula==28) | (*copula==29) | (*copula==30)))	// 90 rotated copulas
+  if(((*copula==23) | (*copula==24) | (*copula==26) | (*copula==27) | (*copula==28) | (*copula==29) | (*copula==30)))	// 90? rotated copulas
     {
 	  ncopula = (*copula)-20;
       for (i = 0; i < *n; ++i) {negv[i] = 1 - v[i];}
 	  diff2hfunc(u, negv, n, nparam, &ncopula, out);
 	  //for (i = 0; i < *n; i++) {out[i]=-out[i];}
     }
-  else if(((*copula==33) | (*copula==34) | (*copula==36) | (*copula==37) | (*copula==38) | (*copula==39) | (*copula==40)))	// 270 rotated copulas
+  else if(((*copula==33) | (*copula==34) | (*copula==36) | (*copula==37) | (*copula==38) | (*copula==39) | (*copula==40)))	// 270? rotated copulas
     {
 	  ncopula = (*copula)-30;
       for (i = 0; i < *n; ++i) {negu[i] = 1 - u[i];}
 	  diff2hfunc(negu, v, n, nparam, &ncopula, out);
 	  for (i = 0; i < *n; i++) {out[i]=-out[i];}
     }
-  else if(((*copula==13) | (*copula==14) | (*copula==16) | (*copula==17) | (*copula==18) | (*copula==19) | (*copula==20)))	// 180 rotated copulas
+  else if(((*copula==13) | (*copula==14) | (*copula==16) | (*copula==17) | (*copula==18) | (*copula==19) | (*copula==20)))	// 180? rotated copulas
 	{
 		ncopula = (*copula)-10;
 		for (i = 0; i < *n; ++i) 
@@ -122,7 +122,7 @@ void diff2hfunc_mod2(double* v, double* u, int* n, double* param, int* copula, d
   nparam[0]=-param[0];
   nparam[1]=-param[1];
 
-if((*copula==43))
+if((*copula)==43)
 	{
 		ncopula=3;
 		if(param[0] > 0){
@@ -137,7 +137,7 @@ if((*copula==43))
 	  diffhfunc(negv, u, n, nparam, &ncopula, out2);
 	  for (i = 0; i < *n; i++) {out[i]=-out[i]*4/pow(1+param[0],4)-out2[i]*4/pow(1+param[0],3);};
 		}
-	}else if((*copula==44))
+	}else if((*copula)==44)
 	{
 		ncopula=4;
 		if(param[0] > 0){
@@ -153,20 +153,20 @@ if((*copula==43))
 			for (i = 0; i < *n; i++) {out[i]=-out[i]/pow(1+param[0],4)-out2[i]*2/pow(1+param[0],3);};
 		}
 	}else{
-  if(((*copula==23) | (*copula==24) | (*copula==26) | (*copula==27) | (*copula==28) | (*copula==29) | (*copula==30)))	// 90 rotated copulas
+  if(((*copula==23) | (*copula==24) | (*copula==26) | (*copula==27) | (*copula==28) | (*copula==29) | (*copula==30)))	// 90? rotated copulas
     {
 	  ncopula = (*copula)-20;
       for (i = 0; i < *n; ++i) {negv[i] = 1 - v[i];}
 	  diff2hfunc(negv, u, n, nparam, &ncopula, out);
 	  for (i = 0; i < *n; i++) {out[i]=-out[i];};
     }
-  else if(((*copula==33) | (*copula==34) | (*copula==36) | (*copula==37) | (*copula==38) | (*copula==39) | (*copula==40)))	// 270 rotated copulas
+  else if(((*copula==33) | (*copula==34) | (*copula==36) | (*copula==37) | (*copula==38) | (*copula==39) | (*copula==40)))	// 270? rotated copulas
     {
 	  ncopula = (*copula)-30;
       for (i = 0; i < *n; ++i) {negu[i] = 1 - u[i];}
 	  diff2hfunc(v, negu, n, nparam, &ncopula, out);
     }
-  else if(((*copula==13) | (*copula==14) | (*copula==16) | (*copula==17) | (*copula==18) | (*copula==19) | (*copula==20)))	// 180 rotated copulas
+  else if(((*copula==13) | (*copula==14) | (*copula==16) | (*copula==17) | (*copula==18) | (*copula==19) | (*copula==20)))	// 180? rotated copulas
 	{
 		ncopula = (*copula)-10;
 		for (i = 0; i < *n; ++i) 
@@ -381,7 +381,7 @@ void diff2hfunc_v_mod(double* u, double* v, int* n, double* param, int* copula,
   nparam[0]=-param[0];
   nparam[1]=-param[1];
 
-if((*copula==43))
+if((*copula)==43)
 	{
 		ncopula=3;
 		if(param[0] > 0){
@@ -393,7 +393,7 @@ if((*copula==43))
 			diff2hfunc_v(u, negv, n, nparam, &ncopula, out);
 			//for(i=0;i<*n;i++){out[i]=-out[i];}
 		}
-	}else if((*copula==44))
+	}else if((*copula)==44)
 	{
 		ncopula=4;
 		if(param[0] > 0){
@@ -406,20 +406,20 @@ if((*copula==43))
 			//for(i=0;i<*n;i++){out[i]=-out[i];}
 		}
 	}else{
-  if(((*copula==23) | (*copula==24) | (*copula==26) | (*copula==27) | (*copula==28) | (*copula==29) | (*copula==30)))	// 90 rotated copulas
+  if(((*copula==23) | (*copula==24) | (*copula==26) | (*copula==27) | (*copula==28) | (*copula==29) | (*copula==30)))	// 90? rotated copulas
     {
 	  ncopula = (*copula)-20;
       for (i = 0; i < *n; ++i) {negv[i] = 1 - v[i];}
 	  diff2hfunc_v(u, negv, n, nparam, &ncopula, out);
     }
-  else if(((*copula==33) | (*copula==34) | (*copula==36) | (*copula==37) | (*copula==38) | (*copula==39) | (*copula==40)))	// 270 rotated copulas
+  else if(((*copula==33) | (*copula==34) | (*copula==36) | (*copula==37) | (*copula==38) | (*copula==39) | (*copula==40)))	// 270? rotated copulas
     {
 	  ncopula = (*copula)-30;
       for (i = 0; i < *n; ++i) {negu[i] = 1 - u[i];}
 	  diff2hfunc_v(negu, v, n, nparam, &ncopula, out);
 	  for (i = 0; i < *n; i++) {out[i]=-out[i];};
     }
-  else if(((*copula==13) | (*copula==14) | (*copula==16) | (*copula==17) | (*copula==18) | (*copula==19) | (*copula==20)))	// 180 rotated copulas
+  else if(((*copula==13) | (*copula==14) | (*copula==16) | (*copula==17) | (*copula==18) | (*copula==19) | (*copula==20)))	// 180? rotated copulas
 	{
 		ncopula = (*copula)-10;
 		for (i = 0; i < *n; ++i) 
@@ -453,7 +453,7 @@ void diff2hfunc_v_mod2(double* v, double* u, int* n, double* param, int* copula,
   nparam[0]=-param[0];
   nparam[1]=-param[1];
 
-if((*copula==43))
+if((*copula)==43)
 	{
 		ncopula=3;
 		if(param[0] > 0){
@@ -465,7 +465,7 @@ if((*copula==43))
 			diff2hfunc_v(negv, u, n, nparam, &ncopula, out);
 			//for(i=0;i<*n;i++){out[i]=-out[i];}
 		}
-	}else if((*copula==44))
+	}else if((*copula)==44)
 	{
 		ncopula=4;
 		if(param[0] > 0){
@@ -478,20 +478,20 @@ if((*copula==43))
 			//for(i=0;i<*n;i++){out[i]=-out[i];}
 		}
 	}else{
-  if(((*copula==23) | (*copula==24) | (*copula==26) | (*copula==27) | (*copula==28) | (*copula==29) | (*copula==30)))	// 90 rotated copulas
+  if(((*copula==23) | (*copula==24) | (*copula==26) | (*copula==27) | (*copula==28) | (*copula==29) | (*copula==30)))	// 90? rotated copulas
     {
 	  ncopula = (*copula)-20;
       for (i = 0; i < *n; ++i) {negv[i] = 1 - v[i];}
 	  diff2hfunc_v(negv, u, n, nparam, &ncopula, out);
     }
-  else if(((*copula==33) | (*copula==34) | (*copula==36) | (*copula==37) | (*copula==38) | (*copula==39) | (*copula==40)))	// 270 rotated copulas
+  else if(((*copula==33) | (*copula==34) | (*copula==36) | (*copula==37) | (*copula==38) | (*copula==39) | (*copula==40)))	// 270? rotated copulas
     {
 	  ncopula = (*copula)-30;
       for (i = 0; i < *n; ++i) {negu[i] = 1 - u[i];}
 	  diff2hfunc_v(v, negu, n, nparam, &ncopula, out);
 	  for (i = 0; i < *n; i++) {out[i]=-out[i];};
     }
-  else if(((*copula==13) | (*copula==14) | (*copula==16) | (*copula==17) | (*copula==18) | (*copula==19) | (*copula==20)))	// 180 rotated copulas
+  else if(((*copula==13) | (*copula==14) | (*copula==16) | (*copula==17) | (*copula==18) | (*copula==19) | (*copula==20)))	// 180? rotated copulas
 	{
 		ncopula = (*copula)-10;
 		for (i = 0; i < *n; ++i) 
@@ -685,7 +685,7 @@ void diff2hfunc_par_v_mod(double* u, double* v, int* n, double* param, int* copu
   nparam[0]=-param[0];
   nparam[1]=-param[1];
 
-if((*copula==43))
+if((*copula)==43)
 	{
 		ncopula=3;
 		if(param[0] > 0){
@@ -698,7 +698,7 @@ if((*copula==43))
 	  diff2hfunc_par_v(u, negv, n, nparam, &ncopula, out);
 	  for (i = 0; i < *n; i++) {out[i]=-out[i]*2/pow(1+param[0],2);};
 		}
-	}else if((*copula==44))
+	}else if((*copula)==44)
 	{
 		ncopula=4;
 		if(param[0] > 0){
@@ -712,19 +712,19 @@ if((*copula==43))
 	  for (i = 0; i < *n; i++) {out[i]=out[i]/pow(1+param[0],2);};
 		}
 	}else{
-  if(((*copula==23) | (*copula==24) | (*copula==26) | (*copula==27) | (*copula==28) | (*copula==29) | (*copula==30)))	// 90 rotated copulas
+  if(((*copula==23) | (*copula==24) | (*copula==26) | (*copula==27) | (*copula==28) | (*copula==29) | (*copula==30)))	// 90? rotated copulas
     {
 	  ncopula = (*copula)-20;
       for (i = 0; i < *n; ++i) {negv[i] = 1 - v[i];}
 	  diff2hfunc_par_v(u, negv, n, nparam, &ncopula, out);
     }
-  else if(((*copula==33) | (*copula==34) | (*copula==36) | (*copula==37) | (*copula==38) | (*copula==39) | (*copula==40)))	// 270 rotated copulas
+  else if(((*copula==33) | (*copula==34) | (*copula==36) | (*copula==37) | (*copula==38) | (*copula==39) | (*copula==40)))	// 270? rotated copulas
     {
 	  ncopula = (*copula)-30;
       for (i = 0; i < *n; ++i) {negu[i] = 1 - u[i];}
 	  diff2hfunc_par_v(negu, v, n, nparam, &ncopula, out);
     }
-  else if(((*copula==13) | (*copula==14) | (*copula==16) | (*copula==17) | (*copula==18) | (*copula==19) | (*copula==20)))	// 180 rotated copulas
+  else if(((*copula==13) | (*copula==14) | (*copula==16) | (*copula==17) | (*copula==18) | (*copula==19) | (*copula==20)))	// 180? rotated copulas
 	{
 		ncopula = (*copula)-10;
 		for (i = 0; i < *n; ++i) 
@@ -938,7 +938,7 @@ void diff2hfunc_par_v_mod2(double* v, double* u, int* n, double* param, int* cop
   nparam[0]=-param[0];
   nparam[1]=-param[1];
 
-if((*copula==43))
+if((*copula)==43)
 	{
 		ncopula=3;
 		if(param[0] > 0){
@@ -951,7 +951,7 @@ if((*copula==43))
 			diff2hfunc_par_v(negv, u, n, nparam, &ncopula, out);
 			for (i = 0; i < *n; i++) {out[i]=out[i]*2/pow(1+param[0],2);}
 		}
-	}else if((*copula==44))
+	}else if((*copula)==44)
 	{
 		ncopula=4;
 		if(param[0] > 0){
@@ -965,19 +965,19 @@ if((*copula==43))
 			for (i = 0; i < *n; i++) {out[i]=out[i]/pow(1+param[0],2);}
 		}
 	}else{
-  if(((*copula==23) | (*copula==24) | (*copula==26) | (*copula==27) | (*copula==28) | (*copula==29) | (*copula==30)))	// 90 rotated copulas
+  if(((*copula==23) | (*copula==24) | (*copula==26) | (*copula==27) | (*copula==28) | (*copula==29) | (*copula==30)))	// 90? rotated copulas
     {
 	  ncopula = (*copula)-20;
       for (i = 0; i < *n; ++i) {negv[i] = 1 - v[i];}
 	  diff2hfunc_par_v(negv, u, n, nparam, &ncopula, out);
     }
-  else if(((*copula==33) | (*copula==34) | (*copula==36) | (*copula==37) | (*copula==38) | (*copula==39) | (*copula==40)))	// 270 rotated copulas
+  else if(((*copula==33) | (*copula==34) | (*copula==36) | (*copula==37) | (*copula==38) | (*copula==39) | (*copula==40)))	// 270? rotated copulas
     {
 	  ncopula = (*copula)-30;
       for (i = 0; i < *n; ++i) {negu[i] = 1 - u[i];}
 	  diff2hfunc_par_v(v, negu, n, nparam, &ncopula, out);
     }
-  else if(((*copula==13) | (*copula==14) | (*copula==16) | (*copula==17) | (*copula==18) | (*copula==19) | (*copula==20)))	// 180 rotated copulas
+  else if(((*copula==13) | (*copula==14) | (*copula==16) | (*copula==17) | (*copula==18) | (*copula==19) | (*copula==20)))	// 180? rotated copulas
 	{
 		ncopula = (*copula)-10;
 		for (i = 0; i < *n; ++i) 
