@@ -1,3 +1,6 @@
+#if !defined(LOGDERIV_H)
+#define LOGDERIV_H
+
 void difflPDF_rho_tCopula(double* u, double* v, int* n, double* param, int* copula, double* out);
 void difflPDF_nu_tCopula_new(double* u, double* v, int* n, double* param, int* copula, double* out);
 void diff2lPDF_rho_tCopula(double* u, double* v, int* n, double* param, int* copula, double* out);
@@ -9,3 +12,5 @@ void difflPDF(double* u, double* v, int* n, double* param, int* copula, double*
 
 void diff2lPDF_mod(double* u, double* v, int* n, double* param, int* copula, double* out);
 void diff2lPDF(double* u, double* v, int* n, double* param, int* copula, double* out);
+
+#endif
